from setuptools import setup

setup(
   name='safeOptimization',
   version='0.0.1',
   description='Safe Optimization algorithms',
   author='Mohammad Amin Roohi',
   author_email='m5a0r7@gmail.com',
   package_dir={'': 'src'},
   py_modules=['logBarrier']
)